function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef } from 'react';
import PropTypes from 'prop-types';
import ReactEchartsCore from '../Core/EchartsReactCore';
import echarts from 'echarts/lib/echarts';
import { titleTextStyle, lbLegend, lbGrid, lbXAxis, lbYAxis, labelStyle } from '../../itemDefaultConfig';
import Empty from '../Empty';
import { formatNumber } from '../../utils';
var BarChart = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$config = _ref.config,
      title = _ref$config.title,
      legend = _ref$config.legend,
      grid = _ref$config.grid,
      xAxis = _ref$config.xAxis,
      yAxis = _ref$config.yAxis,
      series = _ref$config.series,
      otherConfig = _objectWithoutProperties(_ref$config, ["title", "legend", "grid", "xAxis", "yAxis", "series"]),
      showTitle = _ref.showTitle,
      rotate = _ref.rotate,
      showLabel = _ref.showLabel,
      interval = _ref.interval,
      rest = _objectWithoutProperties(_ref, ["config", "showTitle", "rotate", "showLabel", "interval"]);

  var isArray = Array.isArray;

  var option = _objectSpread({
    title: _objectSpread(_objectSpread({}, titleTextStyle), {}, {
      show: showTitle
    }, title),
    tooltip: {
      trigger: 'axis',
      axisPointer: {
        type: 'shadow'
      }
    },
    legend: _objectSpread(_objectSpread({
      top: showTitle ? 27 : 'top'
    }, lbLegend), legend),
    grid: _objectSpread(_objectSpread({
      top: showTitle ? 66 : 36
    }, lbGrid), grid),
    xAxis: isArray(xAxis) ? xAxis.map(function (item) {
      return _objectSpread(_objectSpread({
        axisLabel: {
          interval: interval ? 'auto' : 0,
          rotate: rotate || 0
        }
      }, lbXAxis), item);
    }) : _objectSpread(_objectSpread({
      axisLabel: {
        interval: interval ? 'auto' : 0,
        rotate: rotate || 0
      }
    }, lbXAxis), xAxis),
    yAxis: isArray(yAxis) ? yAxis.map(function (item) {
      return _objectSpread(_objectSpread({}, lbYAxis), item);
    }) : _objectSpread(_objectSpread({}, lbYAxis), yAxis),
    series: series || []
  }, otherConfig);

  var targetArr = [];
  option.series.forEach(function (item) {
    if (showLabel || item.show) {
      item.label = _objectSpread(_objectSpread({}, labelStyle), {}, {
        formatter: function formatter(_ref2) {
          var value = _ref2.value;
          // 千分位分隔符
          return "".concat(formatNumber(value));
        }
      }, item.label);
    }

    item.barMaxWidth = 100;
    targetArr = targetArr.concat(item.data || []);
  });

  if (!targetArr.length) {
    return /*#__PURE__*/React.createElement(Empty, null);
  }

  return /*#__PURE__*/React.createElement(ReactEchartsCore, _extends({
    echarts: echarts,
    notMerge: true,
    option: option,
    ref: ref
  }, rest));
});
BarChart.propTypes = {
  theme: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
  interval: PropTypes.bool,
  showTitle: PropTypes.bool,
  showLabel: PropTypes.bool,
  style: PropTypes.object,
  className: PropTypes.string,
  config: PropTypes.shape({
    xAxis: PropTypes.oneOfType([PropTypes.array, PropTypes.object]).isRequired,
    yAxis: PropTypes.oneOfType([PropTypes.array, PropTypes.object]).isRequired,
    series: PropTypes.array.isRequired
  }).isRequired,
  rotate: PropTypes.number
};
BarChart.defaultProps = {
  style: {},
  classname: '',
  theme: 'macarons',
  rotate: 0,
  showTitle: false,
  interval: true,
  showLabel: false,
  config: {
    title: {},
    legend: {},
    toolbox: {},
    grid: {},
    xAxis: [{
      data: ['示意1', '示意2']
    }],
    yAxis: [_objectSpread({}, lbYAxis)],
    series: [{
      data: [200, 600],
      type: 'bar',
      name: '柱状图'
    }]
  }
};
export default BarChart;